from ..UtilityAndView.abaqusConstants import *
from .._decorators import abaqus_class_doc, abaqus_method_doc


@abaqus_class_doc
class SymbolDisplayOptions:
    """The SymbolDisplayOptions object stores settings that specify how the assembly is
    displayed in a particular viewport. The SymbolDisplayOptions object has no constructor.
    When you create a new viewport, the settings are copied from the current viewport.

    .. note::
        This object can be accessed by:

        .. code-block:: python

            session.viewports[name].assemblyDisplay.symbolOptions
            session.viewports[name].layers[name].assemblyDisplay.symbolOptions
    """

    @abaqus_method_doc
    def setValues(
        self,
        otherSymbolSize: int = 12,
        arrowSymbolSize: int = 12,
        faceSymbolDensity: int = 5,
        edgeSymbolDensity: int = 5,
        meshSymbolFraction: float = 1,
        showFields: Boolean = ON,
    ):
        """This method modifies the SymbolDisplayOptions object.

        Parameters
        ----------
        otherSymbolSize
            An Int specifying the size of the scalar attribute symbols. Possible values are 1 ≤
            **scalarSymbolSize** ≤ 30. The default value is 12.
        arrowSymbolSize
            An Int specifying the size of the vector and tensor attribute symbols. Possible values
            are 1 ≤ **vectorSymbolSize** ≤ 30. The default value is 12.
        faceSymbolDensity
            An Int specifying the relative density of the attribute symbols drawn on geometric
            faces. Possible values are 1 ≤ **faceSymbolDensity** ≤ 10. The default value is 5.
        edgeSymbolDensity
            An Int specifying the relative density of the attribute symbols drawn on geometric
            edges. Possible values are 1 ≤ **edgeSymbolDensity** ≤ 10. The default value is 5.
        meshSymbolFraction
            A Float specifying the fraction of the attribute symbols drawn on orphan mesh regions.
            Possible values are 0.0 ≤ **meshSymbolFraction** ≤ 1.0. The default value is 1.0.
        showFields
            A Boolean specifying whether symbols should be scaled based on analytical field value.
            The default value is ON.
        """
        ...



from .GeometricRestriction import GeometricRestriction
from ..Region.Region import Region
from ..UtilityAndView.abaqusConstants import *
from .._decorators import abaqus_class_doc, abaqus_method_doc


@abaqus_class_doc
class ShapePlanarSymmetry(GeometricRestriction):
    """The ShapePlanarSymmetry object defines a shape planar symmetry geometric restriction.
    The ShapePlanarSymmetry object is derived from the GeometricRestriction object.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import optimization
            mdb.models[name].optimizationTasks[name].geometricRestrictions[name]
    """

    #: A String specifying the geometric restriction repository key.
    name: str

    #: A :py:class:`~abaqus.BasicGeometry.VertexArray.VertexArray` object of length 2 specifying the vector positioned at the **csys** origin
    #: that is normal to the symmetry plane. Instead of through a ConstrainedSketchVertex, each point may be
    #: specified through a tuple of coordinates.
    clientDirection: tuple

    #: A :py:class:`~abaqus.Region.Region.Region` object specifying the region to which the geometric restriction is applied.
    #: When used with a TopologyTask, there is no default value. When used with a ShapeTask,
    #: the default value is MODEL.
    region: Region

    #: None or a DatumCsys object specifying the local coordinate system. If **csys** = None, the
    #: global coordinate system is used. When this member is queried, it returns an Int. The
    #: default value is None.
    csys: int = None

    #: A SymbolicConstant specifying the rule for determining the main node. Possible values
    #: are MAXIMUM and MINIMUM. The default value is MAXIMUM.
    masterPointDetermination: SymbolicConstant = MAXIMUM

    #: A Boolean specifying whether to ignore the geometric restriction in the first design
    #: cycle. The default value is ON.
    presumeFeasibleRegionAtStart: Boolean = ON

    #: A Float specifying the geometric tolerance in the 1-direction. The default value is
    #: 0.01.
    tolerance1: float = 0

    #: A Float specifying the geometric tolerance in the 2-direction. The default value is
    #: 0.01.
    tolerance2: float = 0

    #: A Float specifying the geometric tolerance in the 3-direction. The default value is
    #: 0.01.
    tolerance3: float = 0

    @abaqus_method_doc
    def __init__(
        self,
        name: str,
        clientDirection: tuple,
        region: Region,
        csys: int = None,
        masterPointDetermination: SymbolicConstant = MAXIMUM,
        presumeFeasibleRegionAtStart: Boolean = ON,
        tolerance1: float = 0,
        tolerance2: float = 0,
        tolerance3: float = 0,
    ):
        """This method creates a ShapePlanarSymmetry object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].optimizationTasks[name].ShapePlanarSymmetry

        Parameters
        ----------
        name
            A String specifying the geometric restriction repository key.
        clientDirection
            A :py:class:`~abaqus.BasicGeometry.VertexArray.VertexArray` object of length 2 specifying the vector positioned at the **csys** origin
            that is normal to the symmetry plane. Instead of through a ConstrainedSketchVertex, each point may be
            specified through a tuple of coordinates.
        region
            A :py:class:`~abaqus.Region.Region.Region` object specifying the region to which the geometric restriction is applied.
            When used with a TopologyTask, there is no default value. When used with a ShapeTask,
            the default value is MODEL.
        csys
            None or a DatumCsys object specifying the local coordinate system. If **csys** = None, the
            global coordinate system is used. When this member is queried, it returns an Int. The
            default value is None.
        masterPointDetermination
            A SymbolicConstant specifying the rule for determining the master node. Possible values
            are MAXIMUM and MINIMUM. The default value is MAXIMUM.
        presumeFeasibleRegionAtStart
            A Boolean specifying whether to ignore the geometric restriction in the first design
            cycle. The default value is ON.
        tolerance1
            A Float specifying the geometric tolerance in the 1-direction. The default value is
            0.01.
        tolerance2
            A Float specifying the geometric tolerance in the 2-direction. The default value is
            0.01.
        tolerance3
            A Float specifying the geometric tolerance in the 3-direction. The default value is
            0.01.

        Returns
        -------
        ShapePlanarSymmetry
            A :py:class:`~abaqus.Optimization.ShapePlanarSymmetry.ShapePlanarSymmetry` object.
        """
        super().__init__()

    @abaqus_method_doc
    def setValues(
        self,
        csys: int = None,
        masterPointDetermination: SymbolicConstant = MAXIMUM,
        presumeFeasibleRegionAtStart: Boolean = ON,
        tolerance1: float = 0,
        tolerance2: float = 0,
        tolerance3: float = 0,
    ):
        """This method modifies the ShapePlanarSymmetry object.

        Parameters
        ----------
        csys
            None or a DatumCsys object specifying the local coordinate system. If **csys** = None, the
            global coordinate system is used. When this member is queried, it returns an Int. The
            default value is None.
        masterPointDetermination
            A SymbolicConstant specifying the rule for determining the master node. Possible values
            are MAXIMUM and MINIMUM. The default value is MAXIMUM.
        presumeFeasibleRegionAtStart
            A Boolean specifying whether to ignore the geometric restriction in the first design
            cycle. The default value is ON.
        tolerance1
            A Float specifying the geometric tolerance in the 1-direction. The default value is
            0.01.
        tolerance2
            A Float specifying the geometric tolerance in the 2-direction. The default value is
            0.01.
        tolerance3
            A Float specifying the geometric tolerance in the 3-direction. The default value is
            0.01.
        """
        ...



from ..._decorators import abaqus_class_doc, abaqus_method_doc

@abaqus_class_doc
class ConstrainedSketchParameter:
    """The ConstrainedSketchParameter object stores the definition of a parameter in the
    sketch.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import sketch
            mdb.models[name].sketches[name].parameters[i]
    """

    #: A String specifying the name of the ConstrainedSketchParameter object.
    name: str = ""

    #: A String specifying the path to the ConstrainedSketchDimension that depends on this
    #: ConstrainedSketchParameter.
    path: str = ""

    #: A String specifying an expression or value associated with this
    #: ConstrainedSketchParameter.
    expression: str = ""

    #: A String specifying the name of the ConstrainedSketchParameter that appears before this
    #: one in the ordered list.
    previousParameter: str = ""

    @abaqus_method_doc
    def Parameter(
        self,
        name: str,
        path: str = "",
        expression: str = "",
        previousParameter: str = "",
    ):
        """This method creates a parameter and optionally associates a dimension with this
        parameter.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].sketches[name].ConstrainedSketchParameter

        Parameters
        ----------
        name
            A String specifying the name of the ConstrainedSketchParameter object. No two parameters
            in the same ConstrainedSketch can have the same name.
        path
            A String specifying the ConstrainedSketchDimension object with which this parameter is
            associated.
        expression
            A String specifying the expression or value associated with the
            ConstrainedSketchParameter.
        previousParameter
            A String specifying the name of the previous ConstrainedSketchParameter, if it exists.
            The **previousParameter** argument implies an order among the parameters. No two
            parameters can reference the same parameter as the previous parameter.

        Returns
        -------
        ConstrainedSketchParameter
            A :py:class:`~abaqus.Sketcher.ConstrainedSketchParameter.ConstrainedSketchParameter.ConstrainedSketchParameter` object.

        """
        ...



from .....UtilityAndView.abaqusConstants import *
from ....._decorators import abaqus_class_doc, abaqus_method_doc


@abaqus_class_doc
class DruckerPragerHardening:
    r"""The DruckerPragerHardening object specifies hardening for Drucker-Prager plasticity
    models.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import material
            mdb.models[name].materials[name].druckerPrager.druckerPragerHardening
            import odbMaterial
            session.odbs[name].materials[name].druckerPrager.druckerPragerHardening

        The table data for this object are:

        - Yield stress.
        - Absolute value of the corresponding plastic strain. (The first tabular value
          entered must always be zero.)
        - Equivalent plastic strain rate, :math:`\dot{\bar{\varepsilon}}{ }^{p l}`, for which this 
          hardening curve applies.
        - Temperature, if the data depend on temperature.
        - Value of the first field variable, if the data depend on field variables.
        - Value of the second field variable.
        - Etc.

        The corresponding analysis keywords are:

        - DRUCKER PRAGER HARDENING
    """

    @abaqus_method_doc
    def __init__(
        self,
        table: tuple,
        type: SymbolicConstant = COMPRESSION,
        rate: Boolean = OFF,
        temperatureDependency: Boolean = OFF,
        dependencies: int = 0,
    ):
        """This method creates a DruckerPragerHardening object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].materials[name].druckerPrager.DruckerPragerHardening
                    session.odbs[name].materials[name].druckerPrager.DruckerPragerHardening
            
        Parameters
        ----------
        table
            A sequence of sequences of Floats specifying the items described below. 
        type
            A SymbolicConstant specifying the type of data defining the hardening behavior. Possible 
            values are COMPRESSION, TENSION, and SHEAR. The default value is COMPRESSION. 
        rate
            A Boolean specifying whether the data depend on rate. The default value is OFF. 
        temperatureDependency
            A Boolean specifying whether the data depend on temperature. The default value is OFF. 
        dependencies
            An Int specifying the number of field variable dependencies. The default value is 0. 

        Returns
        -------
        DruckerPragerHardening
            A :py:class:`~abaqus.Material.Plastic.DruckerPrager.Extended.DruckerPragerHardening.DruckerPragerHardening` object. 

        Raises
        ------
        RangeError
        """
        ...

    @abaqus_method_doc
    def setValues(self, *args, **kwargs):
        """This method modifies the DruckerPragerHardening object.

        Raises
        ------
        RangeError
        """
        ...



from .._decorators import abaqus_class_doc


@abaqus_class_doc
class DesignResponse:
    """The DesignResponse object is the abstract base type for other DesignResponse objects.
    The DesponseResponse object has no explicit constructor. The methods and members of the
    DesignResponse object are common to all objects derived from DesignResponse.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import optimization
            mdb.models[name].optimizationTasks[name].designResponses[name]
    """

    #: A String specifying the design response repository key.
    name: str = ""



from .Interaction import Interaction
from ..Region.Region import Region
from ..UtilityAndView.abaqusConstants import *
from .._decorators import abaqus_class_doc, abaqus_method_doc


@abaqus_class_doc
class FluidCavity(Interaction):
    """The FluidCavity object defines a surface-based cavity.
    The FluidCavity object is derived from the Interaction object.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import interaction
            mdb.models[name].interactions[name]

        The corresponding analysis keywords are:

        - FLUID CAVITY
    """

    #: A String specifying the repository key.
    name: str

    #: A String specifying the name of the step in which the FluidCavity object is created.
    createStepName: str

    #: A :py:class:`~abaqus.Region.Region.Region` object specifying the fluid cavity reference point.
    cavityPoint: Region

    #: A :py:class:`~abaqus.Region.Region.Region` object specifying the surface forming the boundary of the fluid cavity.
    cavitySurface: Region

    #: A String specifying the FluidCavityProperty object associated with this interaction.
    interactionProperty: str

    #: A Float specifying the magnitude of the ambient pressure. The default value is 0.0.
    ambientPressure: float = 0

    #: A Float specifying the out-of-plane thickness of the surface for two-dimensional models.
    #: This argument is valid only when using two-dimensional models. The default value is 1.0.
    thickness: float = 1

    #: A Boolean specifying whether adiabatic behavior is assumed for the ideal gas. This
    #: argument is valid only when **interactionProperty** specifies a pneumatic definition. The
    #: default value is OFF.
    useAdiabatic: Boolean = OFF

    #: A Boolean specifying whether the analysis will check the consistency of the surface
    #: normals. The default value is ON.
    checkNormals: Boolean = ON

    @abaqus_method_doc
    def __init__(
        self,
        name: str,
        createStepName: str,
        cavityPoint: Region,
        cavitySurface: Region,
        interactionProperty: str,
        ambientPressure: float = 0,
        thickness: float = 1,
        useAdiabatic: Boolean = OFF,
        checkNormals: Boolean = ON,
    ):
        """This method creates an FluidCavity object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].FluidCavity

        Parameters
        ----------
        name
            A String specifying the repository key.
        createStepName
            A String specifying the name of the step in which the FluidCavity object is created.
        cavityPoint
            A :py:class:`~abaqus.Region.Region.Region` object specifying the fluid cavity reference point.
        cavitySurface
            A :py:class:`~abaqus.Region.Region.Region` object specifying the surface forming the boundary of the fluid cavity.
        interactionProperty
            A String specifying the FluidCavityProperty object associated with this interaction.
        ambientPressure
            A Float specifying the magnitude of the ambient pressure. The default value is 0.0.
        thickness
            A Float specifying the out-of-plane thickness of the surface for two-dimensional models.
            This argument is valid only when using two-dimensional models. The default value is 1.0.
        useAdiabatic
            A Boolean specifying whether adiabatic behavior is assumed for the ideal gas. This
            argument is valid only when **interactionProperty** specifies a pneumatic definition. The
            default value is OFF.
        checkNormals
            A Boolean specifying whether the analysis will check the consistency of the surface
            normals. The default value is ON.

        Returns
        -------
        FluidCavity
            A :py:class:`~abaqus.Interaction.FluidCavity.FluidCavity` object.
        """
        super().__init__()

    @abaqus_method_doc
    def setValues(
        self,
        ambientPressure: float = 0,
        thickness: float = 1,
        useAdiabatic: Boolean = OFF,
        checkNormals: Boolean = ON,
    ):
        """This method modifies the FluidCavity object.

        Parameters
        ----------
        ambientPressure
            A Float specifying the magnitude of the ambient pressure. The default value is 0.0.
        thickness
            A Float specifying the out-of-plane thickness of the surface for two-dimensional models.
            This argument is valid only when using two-dimensional models. The default value is 1.0.
        useAdiabatic
            A Boolean specifying whether adiabatic behavior is assumed for the ideal gas. This
            argument is valid only when **interactionProperty** specifies a pneumatic definition. The
            default value is OFF.
        checkNormals
            A Boolean specifying whether the analysis will check the consistency of the surface
            normals. The default value is ON.
        """
        ...



from .._decorators import abaqus_class_doc, abaqus_method_doc

@abaqus_class_doc
class TransverseShearShell:
    """The TransverseShearShell object defines the transverse shear stiffness properties of a
    shell section.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import section
            mdb.models[name].sections[name].transverseShear
            import odbSection
            session.odbs[name].sections[name].transverseShear

        The corresponding analysis keywords are:

        - TRANSVERSE SHEAR STIFFNESS
    """

    #: A Float specifying the shear stiffness of the section in the first direction.
    k11: float

    #: A Float specifying the shear stiffness of the section in the second direction.
    k22: float

    #: A Float specifying the coupling term in the shear stiffness of the section.
    k12: float

    @abaqus_method_doc
    def __init__(self, k11: float, k22: float, k12: float):
        """This method creates a TransverseShearShell object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].sections[name].TransverseShearShell
                session.odbs[name].sections[name].TransverseShearShell

        Parameters
        ----------
        k11
            A Float specifying the shear stiffness of the section in the first direction.
        k22
            A Float specifying the shear stiffness of the section in the second direction.
        k12
            A Float specifying the coupling term in the shear stiffness of the section.

        Returns
        -------
        TransverseShearShell
            A :py:class:`~abaqus.Section.TransverseShearShell.TransverseShearShell` object.
        """
        ...

    @abaqus_method_doc
    def setValues(self, *args, **kwargs):
        """This method modifies the TransverseShearShell object."""
        ...
